@@ -1806,6 +1806,8 @@ bool FwCompsMgr::queryFwInfo(fwInfoT* query, bool next_boot_fw_ver)
     query->encryption = mgir.fw_info.encryption;
     query->signed_fw = _compsQueryMap[FwComponent::COMPID_BOOT_IMG].comp_cap.signed_updates_only;
     query->ini_file_version = mgir.fw_info.ini_file_version;
+    query->geo_address = mgir.hw_info.ga;
+    query->geo_address_valid = mgir.hw_info.ga_valid;
 
     /* Since in switches MGIR 'dev' field is used to indicate dev-branch instead of the original purpose for dev-secure, */
     /* we now read from a new field called 'dev_sc' to determine if the switch is dev-secure */
@@ -1816,7 +1818,9 @@ bool FwCompsMgr::queryFwInfo(fwInfoT* query, bool next_boot_fw_ver)
         {
             query->security_type.dev_fw = mgir.fw_info.dev_sc;
         }
-        if (dm_dev_is_fs5(dm_device_id))
+        if (dm_dev_is_fs5(dm_device_id) && query->life_cycle.value == FS5_LC_PRE_PRODUCTION) // Other LC values returned
+                                                                                             // from MGIR are translated
+                                                                                             // to FS4 LC values.
         {
             query->life_cycle.version_field = 1;
         }
