@@ -131,13 +131,23 @@ static struct pci_device_id supported_pci_devices[] = {
 /* Allow minor numbers 0-255 */
 #define MAXMINOR 256
 #define BUFFER_SIZE 256
-#define MLNX_VENDOR_SPECIFIC_CAP_ID 0x9
+#define VENDOR_SPECIFIC_CAP_ID 0x9
 #define CRSPACE_DOMAIN 0x2
 #define AS_ICMD 0x3
 #define AS_CR_SPACE 0x2
 #define AS_SEMAPHORE 0xa
+#define AS_RECOVERY 0xc
+#define AS_PCI_ICMD 0x103
+#define AS_PCI_CRSPACE 0x102
+#define AS_PCI_SEMAPHORE 0x10a
 
-/* PCI address space related enum*/
+/* Mellanox VSC */
+#define MLX_VSC_TYPE_OFFSET 24
+#define MLX_VSC_TYPE_LEN 8
+#define FUNCTIONAL_VSC 0
+#define RECOVERY_VSC 2
+
+/* PCI FUNCTIONAL VSC address space related enum*/
 enum
 {
     PCI_CAP_PTR = 0x34,
@@ -157,6 +167,11 @@ enum
 
     PCI_STATUS_BIT_OFFS = 29,
     PCI_STATUS_BIT_LEN = 3,
+
+    PCI_SYNDROME_BIT_OFFSET = 30,
+    PCI_SYNDROME_BIT_LEN = 1,
+    PCI_SYNDROME_CODE_BIT_OFFSET = 24,
+    PCI_SYNDROME_CODE_BIT_LEN = 4,
 };
 
 /* Mellanox vendor specific enum */
@@ -184,7 +199,53 @@ enum
 
 // VSEC supported macro
 #define VSEC_FULLY_SUPPORTED(dev) \
-    (((dev)->vendor_specific_cap) && ((dev)->spaces_support_status == SS_ALL_SPACES_SUPPORTED))
+    (((dev)->functional_vsc_offset) && ((dev)->spaces_support_status == SS_ALL_SPACES_SUPPORTED))
+
+int check_syndrome(struct mst_dev_data* dev)
+{
+    // In case syndrome is set, if syndrome_code is 0x3 (address_out_of_range), return the syndrome_code, so that the
+    // ioctl will fail and then we'll retry with PCI space.
+    int error = 0;
+    unsigned int syndrome = 0;
+    error = pci_read_config_dword(dev->pci_dev, dev->addr_reg, &syndrome); // addr_reg should be vsec+0x10
+    CHECK_PCI_READ_ERROR(error, dev->addr_reg); // dev->addr_reg equivalent in MFT: nnt_device->pciconf_device.address_offset
+    syndrome = EXTRACT(syndrome, PCI_SYNDROME_BIT_OFFSET, PCI_SYNDROME_BIT_LEN);
+    if (syndrome)
+    {
+        unsigned int control_offset = dev->functional_vsc_offset + PCI_CTRL_OFFSET;
+        unsigned int syndrome_code = 0;
+
+        /* Read value from control offset. */
+        error = pci_read_config_dword(dev->pci_dev, control_offset, &syndrome_code);
+        CHECK_PCI_READ_ERROR(error, control_offset);
+
+        syndrome_code = EXTRACT(syndrome_code, PCI_SYNDROME_CODE_BIT_OFFSET, PCI_SYNDROME_CODE_BIT_LEN);
+        if (syndrome_code == ADDRESS_OUT_OF_RANGE)
+        {
+            error = syndrome_code;
+        }
+    }
+ReturnOnFinished:
+    return error;
+}
+
+static int _update_vsc_type(struct mst_dev_data* dev)
+{
+    unsigned int vsc_first_dword;
+    u_int8_t vsc_type = 0;
+    int ret = pci_read_config_dword(dev->pci_dev, dev->functional_vsc_offset, &vsc_first_dword);
+    if (ret)
+    {
+        return ret;
+    }
+    vsc_type = EXTRACT(vsc_first_dword, MLX_VSC_TYPE_OFFSET, MLX_VSC_TYPE_LEN);
+    if (vsc_type == RECOVERY_VSC)
+    {
+        dev->recovery_vsc_offset = dev->functional_vsc_offset;
+        dev->functional_vsc_offset = 0;
+    }
+    return 0;
+}
 
 static int _vendor_specific_sem(struct mst_dev_data* dev, int state)
 {
@@ -195,7 +256,7 @@ static int _vendor_specific_sem(struct mst_dev_data* dev, int state)
 
     if (!state)
     { // unlock
-        ret = pci_write_config_dword(dev->pci_dev, dev->vendor_specific_cap + PCI_SEMAPHORE_OFFSET, 0);
+        ret = pci_write_config_dword(dev->pci_dev, dev->functional_vsc_offset + PCI_SEMAPHORE_OFFSET, 0);
         if (ret)
             return ret;
     }
@@ -206,7 +267,7 @@ static int _vendor_specific_sem(struct mst_dev_data* dev, int state)
             if (retries > SEM_MAX_RETRIES)
                 return -1;
             // read semaphore untill 0x0
-            ret = pci_read_config_dword(dev->pci_dev, dev->vendor_specific_cap + PCI_SEMAPHORE_OFFSET, &lock_val);
+            ret = pci_read_config_dword(dev->pci_dev, dev->functional_vsc_offset + PCI_SEMAPHORE_OFFSET, &lock_val);
             if (ret)
                 return ret;
 
@@ -217,15 +278,15 @@ static int _vendor_specific_sem(struct mst_dev_data* dev, int state)
                 continue;
             }
             // read ticket
-            ret = pci_read_config_dword(dev->pci_dev, dev->vendor_specific_cap + PCI_COUNTER_OFFSET, &counter);
+            ret = pci_read_config_dword(dev->pci_dev, dev->functional_vsc_offset + PCI_COUNTER_OFFSET, &counter);
             if (ret)
                 return ret;
             // write ticket to semaphore dword
-            ret = pci_write_config_dword(dev->pci_dev, dev->vendor_specific_cap + PCI_SEMAPHORE_OFFSET, counter);
+            ret = pci_write_config_dword(dev->pci_dev, dev->functional_vsc_offset + PCI_SEMAPHORE_OFFSET, counter);
             if (ret)
                 return ret;
             // read back semaphore make sure ticket == semaphore else repeat
-            ret = pci_read_config_dword(dev->pci_dev, dev->vendor_specific_cap + PCI_SEMAPHORE_OFFSET, &lock_val);
+            ret = pci_read_config_dword(dev->pci_dev, dev->functional_vsc_offset + PCI_SEMAPHORE_OFFSET, &lock_val);
             if (ret)
                 return ret;
             retries++;
@@ -245,7 +306,7 @@ static int _wait_on_flag(struct mst_dev_data* dev, u8 expected_val)
         if (retries > IFC_MAX_RETRIES)
             return -1;
 
-        ret = pci_read_config_dword(dev->pci_dev, dev->vendor_specific_cap + PCI_ADDR_OFFSET, &flag);
+        ret = pci_read_config_dword(dev->pci_dev, dev->functional_vsc_offset + PCI_ADDR_OFFSET, &flag);
         if (ret)
             return ret;
 
@@ -265,15 +326,15 @@ static int _set_addr_space(struct mst_dev_data* dev, u16 space)
     u32 val;
     int ret;
 
-    ret = pci_read_config_dword(dev->pci_dev, dev->vendor_specific_cap + PCI_CTRL_OFFSET, &val);
+    ret = pci_read_config_dword(dev->pci_dev, dev->functional_vsc_offset + PCI_CTRL_OFFSET, &val);
     if (ret)
         return ret;
     val = MERGE(val, space, PCI_SPACE_BIT_OFFS, PCI_SPACE_BIT_LEN);
-    ret = pci_write_config_dword(dev->pci_dev, dev->vendor_specific_cap + PCI_CTRL_OFFSET, val);
+    ret = pci_write_config_dword(dev->pci_dev, dev->functional_vsc_offset + PCI_CTRL_OFFSET, val);
     if (ret)
         return ret;
     // read status and make sure space is supported
-    ret = pci_read_config_dword(dev->pci_dev, dev->vendor_specific_cap + PCI_CTRL_OFFSET, &val);
+    ret = pci_read_config_dword(dev->pci_dev, dev->functional_vsc_offset + PCI_CTRL_OFFSET, &val);
     if (ret)
         return ret;
 
@@ -299,11 +360,11 @@ static int _pciconf_rw(struct mst_dev_data* dev, unsigned int offset, u32* data,
     if (rw == WRITE_OP)
     {
         // write data
-        ret = pci_write_config_dword(dev->pci_dev, dev->vendor_specific_cap + PCI_DATA_OFFSET, *data);
+        ret = pci_write_config_dword(dev->pci_dev, dev->functional_vsc_offset + PCI_DATA_OFFSET, *data);
         if (ret)
             return ret;
         // write address
-        ret = pci_write_config_dword(dev->pci_dev, dev->vendor_specific_cap + PCI_ADDR_OFFSET, address);
+        ret = pci_write_config_dword(dev->pci_dev, dev->functional_vsc_offset + PCI_ADDR_OFFSET, address);
         if (ret)
             return ret;
         // wait on flag
@@ -312,16 +373,20 @@ static int _pciconf_rw(struct mst_dev_data* dev, unsigned int offset, u32* data,
     else
     {
         // write address
-        ret = pci_write_config_dword(dev->pci_dev, dev->vendor_specific_cap + PCI_ADDR_OFFSET, address);
+        ret = pci_write_config_dword(dev->pci_dev, dev->functional_vsc_offset + PCI_ADDR_OFFSET, address);
         if (ret)
             return ret;
         // wait on flag
         ret = _wait_on_flag(dev, 1);
         // read data
-        ret = pci_read_config_dword(dev->pci_dev, dev->vendor_specific_cap + PCI_DATA_OFFSET, data);
+        ret = pci_read_config_dword(dev->pci_dev, dev->functional_vsc_offset + PCI_DATA_OFFSET, data);
         if (ret)
             return ret;
     }
+    if (dev->pci_vsec_space_fully_supported == 1)
+    {
+        ret = check_syndrome(dev);
+    }
     return ret;
 }
 
@@ -367,10 +432,18 @@ static int _block_op(struct mst_dev_data* dev, int space, unsigned int offset, i
 
     for (i = 0; i < size; i += 4)
     {
-        if (_pciconf_rw(dev, offset + i, &(data[(i >> 2)]), rw))
+        int result = _pciconf_rw(dev, offset + i, &(data[(i >> 2)]), rw);
+        if (result != 0)
         {
-            wrote_or_read = i;
-            goto cleanup;
+            if (result == ADDRESS_OUT_OF_RANGE) // Support PCI space
+            {
+                wrote_or_read = -1;
+            }
+            else
+            {
+                wrote_or_read = i;
+            }
+            break;
         }
     }
 cleanup:
@@ -489,9 +562,15 @@ static int read4_block_vsec(struct mst_dev_data* dev, int address_space, unsigne
 
 static int get_space_support_status(struct mst_dev_data* dev)
 {
-    int ret;
+    int ret = 0;
+    // If VSC is of type RECOVERY, all the spaces are not supported
+    if (dev->functional_vsc_offset == RECOVERY_VSC)
+    {
+        dev->spaces_support_status = SS_NOT_ALL_SPACES_SUPPORTED;
+        return 0;
+    }
     //    printk("[MST] Checking if the Vendor CAP %d supports the SPACES in devices\n", vend_cap);
-    if ((!dev->vendor_specific_cap) || (!dev->pci_dev))
+    if ((!dev->functional_vsc_offset) || (!dev->pci_dev))
         return 0;
     if (dev->spaces_support_status != SS_UNINITIALIZED)
         return 0;
@@ -503,7 +582,7 @@ static int get_space_support_status(struct mst_dev_data* dev)
         return 1;
     }
 
-    if (_set_addr_space(dev, AS_CR_SPACE))
+    else if (_set_addr_space(dev, AS_CR_SPACE))
     {
         capability_support_info_message(dev, CR_SPACE);
         dev->spaces_support_status = SS_NOT_ALL_SPACES_SUPPORTED;
@@ -522,6 +601,14 @@ static int get_space_support_status(struct mst_dev_data* dev)
     {
         dev->spaces_support_status = SS_ALL_SPACES_SUPPORTED;
     }
+    if (_set_addr_space(dev, AS_RECOVERY))
+    {
+        capability_support_info_message(dev, RECOVERY); // this space is supported only for ConnectX8, Quantum3 and above. For recovery from Zombiefish mode.
+    }
+    if (!_set_addr_space(dev, AS_PCI_CRSPACE) && !_set_addr_space(dev, AS_PCI_ICMD) && !_set_addr_space(dev, AS_PCI_SEMAPHORE))
+    {
+        dev->pci_vsec_space_fully_supported = 1; // Support PCI space
+    }
 
     // clear semaphore
     _vendor_specific_sem(dev, 0);
@@ -899,15 +986,15 @@ static int mst_ioctl(struct inode* inode, struct file* file, unsigned int opcode
             paramst.vendor = dev->pci_dev->vendor;
             paramst.subsystem_device = dev->pci_dev->subsystem_device;
             paramst.subsystem_vendor = dev->pci_dev->subsystem_vendor;
-            if (dev->vendor_specific_cap && (dev->spaces_support_status == SS_ALL_SPACES_SUPPORTED ||
+            if (dev->functional_vsc_offset && (dev->spaces_support_status == SS_ALL_SPACES_SUPPORTED ||
                                              dev->spaces_support_status == SS_UNINITIALIZED))
             {
                 // assume supported if SS_UNINITIALIZED (since semaphore is locked)
-                paramst.vendor_specific_cap = dev->vendor_specific_cap;
+                paramst.functional_vsc_offset = dev->functional_vsc_offset;
             }
             else
             {
-                paramst.vendor_specific_cap = 0;
+                paramst.functional_vsc_offset = 0;
             }
             if (copy_to_user(user_buf, &paramst, sizeof(struct mst_params)))
             {
@@ -1264,8 +1351,12 @@ static int mst_ioctl(struct inode* inode, struct file* file, unsigned int opcode
             dev->data_reg = initst.data_reg;
 
             dev->wo_addr = is_wo_gw(dev->pci_dev, initst.addr_reg);
-            dev->vendor_specific_cap = pci_find_capability(dev->pci_dev, MLNX_VENDOR_SPECIFIC_CAP_ID);
-            // mst_info("VSEC SUPP: %#x\n", dev->vendor_specific_cap);
+            dev->functional_vsc_offset = pci_find_capability(dev->pci_dev, VENDOR_SPECIFIC_CAP_ID);
+            _update_vsc_type(dev);
+            // mst_info("dev->functional_vsc_offset: %#x. dev->recovery_vsc_offset: %#x dev->wo_addr:%d.\n", dev->functional_vsc_offset, dev->recovery_vsc_offset, dev->wo_addr);
+
+
+            // mst_info("FUNCTIONAL VSC SUPP: %#x\n", dev->functional_vsc_offset);
             dev->spaces_support_status = SS_UNINITIALIZED; // init on first op
 
             dev->initialized = 1;
@@ -1679,8 +1770,11 @@ static struct mst_dev_data* mst_device_create(enum dev_type type, struct pci_dev
          * Initialize 5th Gen attributes
          */
         dev->wo_addr = is_wo_gw(dev->pci_dev, MST_CONF_ADDR_REG);
-        dev->vendor_specific_cap = pci_find_capability(dev->pci_dev, MLNX_VENDOR_SPECIFIC_CAP_ID);
-        // mst_info("VSEC SUPP: %#x\n", dev->vendor_specific_cap);
+        dev->functional_vsc_offset = pci_find_capability(dev->pci_dev, VENDOR_SPECIFIC_CAP_ID);
+        _update_vsc_type(dev);
+        // mst_info("dev->functional_vsc_offset: %#x. dev->recovery_vsc_offset: %#x dev->wo_addr:%d.\n", dev->functional_vsc_offset, dev->recovery_vsc_offset, dev->wo_addr);
+
+        // mst_info("FUNCTIONAL VSC SUPP: %#x\n", dev->functional_vsc_offset);
         dev->spaces_support_status = SS_UNINITIALIZED; // init on first op
     }
     dev->initialized = 1;
