@@ -108,6 +108,8 @@ typedef void* trm_ctx;
 #define SPECTRUM4_HW_ID 0x254
 #define INBAND_MAX_REG_SIZE 44
 
+#define VSC_RECOVERY_SPACE_FLASH_GW_BASE_ADDRESS 0x10
+
 /*
  * Device IDs Macros:
  */
@@ -330,11 +332,12 @@ enum CntxCrConstants
     HCR_NEW_GW_GCM_EN_ADDR = 0xf0440,
     // 7th gen flash GW registers addresses
     // QTM3:
-    HCR_7GEN_QTM3_FLASH_CMD = 0x100000,
-    HCR_7GEN_QTM3_FLASH_DATA = 0x100010,
-    HCR_7GEN_QTM3_GCM_EN_ADDR = 0x100028,
-    HCR_7GEN_QTM3_FLASH_ADDR = 0x10003c,
-    HCR_7GEN_QTM3_FLASH_DATA_SIZE = 0x100044,
+    HCR_7GEN_QTM3_FLASH_GW_BASE_ADDR = 0x101000,
+    HCR_7GEN_QTM3_FLASH_CMD = HCR_7GEN_QTM3_FLASH_GW_BASE_ADDR,
+    HCR_7GEN_QTM3_FLASH_DATA = 0x101010,
+    HCR_7GEN_QTM3_GCM_EN_ADDR = 0x101028,
+    HCR_7GEN_QTM3_FLASH_ADDR = 0x10103c,
+    HCR_7GEN_QTM3_FLASH_DATA_SIZE = 0x101044,
     // ARCUSE:
     HCR_7GEN_ARCUSE_FLASH_CMD = 0x101000,
     HCR_7GEN_ARCUSE_FLASH_DATA = 0x101010,
@@ -342,7 +345,8 @@ enum CntxCrConstants
     HCR_7GEN_ARCUSE_FLASH_ADDR = 0x10103c,
     HCR_7GEN_ARCUSE_FLASH_DATA_SIZE = 0x101044,
     // CX8:
-    HCR_7GEN_CX8_FLASH_CMD = 0x8a1000,
+    HCR_7GEN_CX8_FLASH_GW_BASE_ADDR = 0x8a1000,
+    HCR_7GEN_CX8_FLASH_CMD = HCR_7GEN_CX8_FLASH_GW_BASE_ADDR,
     HCR_7GEN_CX8_FLASH_DATA = 0x8a1010,
     HCR_7GEN_CX8_GCM_EN_ADDR = 0x8a1028,
     HCR_7GEN_CX8_FLASH_ADDR = 0x8a103c,
