@@ -39,6 +39,7 @@
 #include <stdio.h>
 #include <string.h>
 #include <string>
+#include <sys/stat.h>
 
 #include "mfa2_buff.h"
 
@@ -64,6 +65,13 @@ bool Mfa2Buffer::loadFile(const std::string& fname)
         return false;
     }
 
+    struct stat st;
+    int status = stat(fname.c_str(), &st);
+    if (status != 0 || S_ISREG(st.st_mode) == 0)
+    {
+        return false;
+    }
+
     // Get file length
     fseek(fp, 0, SEEK_END);
     m_size = ftell(fp);
