@@ -1,5 +1,6 @@
 /*
  * Copyright (C) Jan 2013 Mellanox Technologies Ltd. All rights reserved.
+ * Copyright (c) 2021 NVIDIA CORPORATION & AFFILIATES. All rights reserved.
  *
  * This software is available to you under a choice of one of two
  * licenses.  You may choose to be licensed under the terms of the GNU
@@ -39,14 +40,31 @@
 #include <compatibility.h>
 #include <mtcr.h>
 
-#include "mlxcfg_4thgen_commander.h"
-//#include "mlxcfg_lib.h"
+#ifdef CABLES_SUPP
+#include <cable_access/cdb_cable_commander.h>
+#endif
+
+// #include "mlxcfg_lib.h"
 #include "mlxcfg_commander.h"
 #include "mlxcfg_view.h"
+#include "mlxcfg_utils.h"
+
+
+#define MAX_ERR_STR_LEN 1024
+#define MAX_BUF_SIZE 1024
+#define PRE_ERR_MSG "-E-"
+#define MLNX_RAW_TLV_FILE_SIG "MLNX_RAW_TLV_FILE"
+
+#ifdef MST_UL
+#define NO_DEV_ERR "No devices found."
+#else
+#define NO_DEV_ERR "No devices found, mst might be stopped. You may need to run 'mst start' to load MST modules. "
+#endif
 
 #define DB_NAME ""
 
-typedef enum {
+typedef enum
+{
     Mc_Set,
     Mc_Query,
     Mc_Reset,
@@ -65,8 +83,10 @@ typedef enum {
     Mc_UnknownCmd
 } mlxCfgCmd;
 
-typedef struct QueryOutputItem {
+typedef struct QueryOutputItem
+{
     string mlxconfigName;
+    bool isReadOnly;
     u_int32_t nextVal;
     string strNextVal;
     u_int32_t currVal;
@@ -82,13 +102,29 @@ using namespace std;
 class MlxCfgParams
 {
 public:
-    MlxCfgParams() : device(), rawTlvFile(), NVInputFile(), NVOutputFile(),
-        dbName(DB_NAME), privPemFile(), keyPairUUID(), opensslEngine(),
-        opensslKeyId(), allAttrs(false), cmd(Mc_UnknownCmd), yes(false),
-        force(false), enableVerbosity(false) {}
+    MlxCfgParams() :
+        device(),
+        deviceType(UNSUPPORTED_DEVICE),
+        rawTlvFile(),
+        NVInputFile(),
+        NVOutputFile(),
+        dbName(DB_NAME),
+        privPemFile(),
+        keyPairUUID(),
+        opensslEngine(),
+        opensslKeyId(),
+        allAttrs(false),
+        cmd(Mc_UnknownCmd),
+        yes(false),
+        force(false),
+        enableVerbosity(false)
+    {
+    }
+
     ~MlxCfgParams() {}
 
     std::string device;
+    Device_Type deviceType;
     std::string rawTlvFile;
     std::string NVInputFile;
     std::string NVOutputFile;
@@ -101,52 +137,59 @@ public:
     mlxCfgCmd cmd;
     bool yes;
     std::vector<ParamView> setParams;
-    bool force;// ignore parameter checks
+    bool force; // ignore parameter checks
     bool enableVerbosity;
-
 };
 
 class MlxCfg
 {
 public:
-    MlxCfg() : _mlxParams(), _errStr(), _allInfo(), _devType(DeviceUnknown) {}
-    ~MlxCfg() {};
-    mlxCfgStatus execute(int argc, char *argv[]);
-private:
+    MlxCfg() : _mlxParams(), _errStr(), _devType(DeviceUnknown) {}
+    ~MlxCfg(){};
+    mlxCfgStatus execute(int argc, char* argv[]);
 
+private:
     // User interface and parsing methods
     void printHelp();
     mlxCfgStatus showDevConfs();
+    const char* getDeviceName(mfile* mf);
     void printVersion();
     void printUsage();
-    void printOpening(const char *dev, int devIndex);
+    void printOpening(mfile* mf, const char* dev, int devIndex);
     void printConfHeader(bool showDefualt, bool showNew, bool showCurrent);
-    mlxCfgStatus parseArgs(int argc, char *argv[]);
-    //Helper functions for parse args
-    mlxCfgStatus extractNVInputFile(int argc, char *argv[]);
-    mlxCfgStatus extractNVOutputFile(int argc, char *argv[]);
-    mlxCfgStatus extractSetCfgArgs(int argc, char *argv[]);
-    mlxCfgStatus extractQueryCfgArgs(int argc, char *argv[]);
+    mlxCfgStatus getNumberFromString(const char* str, u_int32_t& num);
+    mlxCfgStatus parseArgs(int argc, char* argv[]);
+    // Helper functions for parse args
+    mlxCfgStatus extractNVInputFile(int argc, char* argv[]);
+    mlxCfgStatus extractNVOutputFile(int argc, char* argv[]);
+    mlxCfgStatus extractSetCfgArgs(int argc, char* argv[]);
+    mlxCfgStatus extractQueryCfgArgs(int argc, char* argv[]);
 
-    void removeContinuanceArray(std::vector<QueryOutputItem>& OutputItemOut, std::vector<QueryOutputItem>& OutputItemIn);
-    void editAndPushItem(std::vector<QueryOutputItem>& queryOutputItemVector, QueryOutputItem& item, u_int32_t arrayIndex);
+    void removeContinuanceArray(std::vector<QueryOutputItem>& OutputItemOut,
+                                std::vector<QueryOutputItem>& OutputItemIn);
+    void
+      editAndPushItem(std::vector<QueryOutputItem>& queryOutputItemVector, QueryOutputItem& item, u_int32_t arrayIndex);
 
-    const char * getConfigWarning(const string & mlx_config_name,
-            const string & set_val);
+    const char* getConfigWarning(const string& mlx_config_name, const string& set_val);
 
     bool tagExsists(string tag);
-    const char* getDeviceName(const char *dev);
 
     // Query cmd
     mlxCfgStatus queryDevsCfg();
-    mlxCfgStatus queryDevCfg(const char *dev, const char *pci = (const char*)NULL, int devIndex = 1, bool printNewCfg = false);
-    mlxCfgStatus queryDevCfg(Commander *commander, const char *dev, const char *pci = (const char*)NULL, int devIndex = 1, bool printNewCfg = false);
+    mlxCfgStatus
+      queryDevCfg(const char* dev, const char* pci = (const char*)NULL, int devIndex = 1, bool printNewCfg = false);
+    mlxCfgStatus queryDevCfg(Commander* commander,
+                             const char* dev,
+                             bool isWriteOperation,
+                             const char* pci = (const char*)NULL,
+                             int devIndex = 1,
+                             bool printNewCfg = false);
 
     // Set cmd
     mlxCfgStatus setDevCfg();
     // reset Cmd
     mlxCfgStatus resetDevsCfg();
-    mlxCfgStatus resetDevCfg(const char *dev);
+    mlxCfgStatus resetDevCfg(const char* dev);
     // Set\Get Raw TLV file
     mlxCfgStatus devRawCfg(RawTlvMode mode);
     mlxCfgStatus backupCfg();
@@ -176,19 +219,16 @@ private:
     // static print functions
     static int printParam(string param, u_int32_t val);
     static int printValue(string strVal, u_int32_t val);
-    static void printSingleParam(const char *name,
-            QueryOutputItem & queryOutItem, u_int8_t verbose, bool printNewCfg);
+    static void printSingleParam(const char* name, QueryOutputItem& queryOutItem, u_int8_t verbose, bool printNewCfg);
 
-
-    bool askUser(const char *question, bool add_prefix=true, bool add_suffix=true);
-    mlxCfgStatus err(bool report, const char *errMsg, ...);
+    bool askUser(const char* question, bool add_prefix = true, bool add_suffix = true);
+    mlxCfgStatus err(bool report, const char* errMsg, ...);
     void printErr();
     // data members
+
     MlxCfgParams _mlxParams;
     std::string _errStr;
-    MlxCfgAllInfo _allInfo;
     dm_dev_id_t _devType;
-
 };
 
 #endif /* MLXCFG_UI_H_ */
