@@ -1,13 +1,33 @@
 /*
- * Copyright (c) 2013-2021 NVIDIA CORPORATION & AFFILIATES. ALL RIGHTS RESERVED.
+ * Copyright (c) 2023 NVIDIA CORPORATION & AFFILIATES. ALL RIGHTS RESERVED.
  *
- * This software product is a proprietary product of Nvidia Corporation and its affiliates
- * (the "Company") and all right, title, and interest in and to the software
- * product, including all associated intellectual property rights, are and
- * shall remain exclusively with the Company.
+ * This software is available to you under a choice of one of two
+ * licenses.  You may choose to be licensed under the terms of the GNU
+ * General Public License (GPL) Version 2, available from the file
+ * COPYING in the main directory of this source tree, or the
+ * OpenIB.org BSD license below:
  *
- * This software product is governed by the End User License Agreement
- * provided with the software product.
+ *     Redistribution and use in source and binary forms, with or
+ *     without modification, are permitted provided that the following
+ *     conditions are met:
+ *
+ *      - Redistributions of source code must retain the above
+ *        copyright notice, this list of conditions and the following
+ *        disclaimer.
+ *
+ *      - Redistributions in binary form must reproduce the above
+ *        copyright notice, this list of conditions and the following
+ *        disclaimer in the documentation and/or other materials
+ *        provided with the distribution.
+ *
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
+ * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+ * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
+ * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS
+ * BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
+ * ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
+ * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+ * SOFTWARE.
  */
 
 #include <iostream>
@@ -74,6 +94,7 @@ MlxDpa::MlxDpa() :
     _removeAllCertsSpecified(false),
     _removeAllCerts(false),
     _certContainerPath(""),
+     _certContainerType(CertContainerType::UnknownType),
     _command(Unknown)
 {
     InitCmdParser();
@@ -555,6 +576,17 @@ void MlxDpa::SignCertContainer()
 void MlxDpa::SignHostElf()
 {
     const u_int32_t ALIGNMENT = 4;
+
+    if (_outputPath.empty())
+    {
+        _outputPath = _hostELFPath;
+    }
+    else
+    {
+        string cmd("cp " + _hostELFPath + " " + _outputPath);
+        RunCommand(cmd, "Failed to create output file");
+    }
+
     HostElf hostElf(_hostELFPath, _outputPath);
     CryptoDataSection::CertChain certChain;
     unique_ptr<MlxSign::Signer> signer = CreateSigner(_privateKeyPem, _keyLabel);
@@ -585,21 +617,29 @@ void MlxDpa::SignHostElf()
             cryptoDataSectionByteStream.resize(cryptoDataSectionByteStream.size() + paddingSize, 0xff);
         }
 
-        // remove preexisting section to avoid collision
-        string sigSectionName = "sig_" + string(app->name);
-        hostElf.RemoveSection(sigSectionName);
-
-        hostElf.AddSection(sigSectionName, cryptoDataSectionByteStream);
-
         // invoke 3rd party function to update metadata in host elf output file
         FILE* outHostELF = fopen(_outputPath.c_str(), "r+");
         if (outHostELF == NULL)
         {
             throw MlxDpaException("Failed to open Host ELF file with error: %s", strerror(errno));
         }
-        if (updateSigSectionName(outHostELF, app->name, (char*)sigSectionName.c_str()))
+        MLX_DPA_DPRINTF(("Calling updateSignatureData: appName %s, cryptoData size %lu.\n",
+                         app->name,
+                         (long)cryptoDataSectionByteStream.size()));
+        int rc = updateSignatureData(
+          outHostELF, app->name, cryptoDataSectionByteStream.data(), cryptoDataSectionByteStream.size());
+        if (rc != 0)
         {
-            throw MlxDpaException("Failed to update signature section name in metadata for %s.\n", app->name);
+            string err("Failed to add crypto data for app" + string(app->name) + ".");
+            if (rc < 5)
+            {
+                err += " " + updateSigErrors[rc];
+            }
+            throw MlxDpaException(err.c_str());
+        }
+        if (fclose(outHostELF) != 0)
+        {
+            throw MlxDpaException("Failed to close Host ELF file with error: %s", strerror(errno));
         }
     }
 
@@ -647,4 +687,4 @@ int main(int argc, char** argv)
         return 1;
     }
     return 0;
-}
\ No newline at end of file
+}
