@@ -185,7 +185,7 @@ protected:
     u_int32_t _hashes_table_ptr;
     Fs4ImgInfo _fs4ImgInfo;
 
-    bool GetImageSizeFromImageInfo(u_int32_t* imageSize);
+    bool GetEncryptedImageSizeFromImageInfo(u_int32_t* imageSize);
     bool verifyToolsArea(VerifyCallBack verifyCallBackFunc);
     bool verifyTocHeader(u_int32_t tocAddr, bool isDtoc, VerifyCallBack verifyCallBackFunc);
     bool verifyTocEntries(u_int32_t tocAddr,
@@ -207,9 +207,11 @@ protected:
                       bool verbose = false,
                       VerifyCallBack verifyCallBackFunc = (VerifyCallBack)NULL,
                       bool showItoc = false);
+    bool IsDtocExists(bool& dtocExists);
     bool GetHashesTableSize(u_int32_t& size);
     bool GetImageInfo(u_int8_t* buff);
-
+    virtual bool GetDtocAddress(u_int32_t& dTocAddress);
+    bool ParseImageInfoFromEncryptedImage();
 
 private:
 #define PRE_CRC_OUTPUT "    "
@@ -240,7 +242,6 @@ private:
 #endif
     bool PrepItocSectionsForHmac(vector<u_int8_t>& critical, vector<u_int8_t>& non_critical);
     bool CheckSignatures(u_int32_t a[], u_int32_t b[], int n);
-    bool encryptedFwReadImageInfoSection();
     bool CheckDevRSAPublicKeyUUID();
     virtual bool FwQuery(fw_info_t* fwInfo,
                          bool readRom = true,
@@ -384,10 +385,12 @@ private:
       GetPublicKeyFromFile(const char* public_key_file, const char* uuid, image_layout_file_public_keys_3* public_key);
     virtual bool GetFreeSlotInPublicKeys2(const image_layout_public_keys_2& public_keys, u_int32_t& idx);
     virtual bool GetFreeSlotInPublicKeys3(const image_layout_public_keys_3& public_keys, u_int32_t& idx);
-    virtual bool IsPublicKeyAlreadyInPublicKeys2(const image_layout_public_keys_2& public_keys,
-                                                 const image_layout_file_public_keys_2& public_key);
-    virtual bool IsPublicKeyAlreadyInPublicKeys3(const image_layout_public_keys_3& public_keys,
-                                                 const image_layout_file_public_keys_3& public_key);
+    virtual bool FindPublicKeyInPublicKeys2(const image_layout_public_keys_2& public_keys,
+                                            const image_layout_file_public_keys_2& public_key,
+                                            u_int32_t& idx);
+    virtual bool FindPublicKeyInPublicKeys3(const image_layout_public_keys_3& public_keys,
+                                            const image_layout_file_public_keys_3& public_key,
+                                            u_int32_t& idx);
     virtual bool FindImagePublicKeyInPublicKeys2(const image_layout_public_keys_2& public_keys, u_int32_t& idx);
     virtual bool FindImagePublicKeyInPublicKeys3(const image_layout_public_keys_3& public_keys, u_int32_t& idx);
     virtual bool StoreImagePublicKeyInPublicKeys2(const image_layout_file_public_keys_3& public_key);
@@ -397,6 +400,8 @@ private:
                                             image_layout_file_public_keys_3& public_key);
     virtual void PublicKey2ToPublicKey3(const image_layout_file_public_keys_2& public_key_2,
                                         image_layout_file_public_keys_3& public_key_3);
+    virtual void PublicKey3ToPublicKey2(const image_layout_file_public_keys_3& public_key_3,
+                                        image_layout_file_public_keys_2& public_key_2);
     virtual bool ReadPublicKeys2SectionFromFile(const char* fname, image_layout_public_keys_2& public_keys_2_section);
     
     // Members
