@@ -170,7 +170,7 @@ bool Fs5Operations::CheckBoot2(bool fullRead, const char* pref, VerifyCallBack v
     {
         return false;
     }
-    _fwImgInfo.boot2Size = ncoreBCH.u8_stage1_component.u32_binary_len - hashes_table_size;
+    _fwImgInfo.boot2Size = __be32_to_cpu(ncoreBCH.u8_stage1_component.u32_binary_len) - hashes_table_size;
 
     DPRINTF(("FwOperations::CheckBoot2 size = 0x%x\n", _fwImgInfo.boot2Size));
     if (_fwImgInfo.boot2Size > 1048576 || _fwImgInfo.boot2Size < 4)
@@ -505,4 +505,22 @@ bool Fs5Operations::GetMfgInfo(u_int8_t* buff)
         }
     }
     return rc;
+}
+
+bool Fs5Operations::CheckAndDealWithChunkSizes(u_int32_t cntxLog2ChunkSize, u_int32_t imageCntxLog2ChunkSize)
+{
+    if (cntxLog2ChunkSize > 0x19)
+    {
+        return errmsg("Unsupported Device partition size 0x%x", cntxLog2ChunkSize);
+    }
+    if (imageCntxLog2ChunkSize > 0x19)
+    {
+        return errmsg("Unsupported Image partition size 0x%x", imageCntxLog2ChunkSize);
+    }
+    if (cntxLog2ChunkSize != imageCntxLog2ChunkSize)
+    {
+        return errmsg("Device and Image partition size differ(0x%x/0x%x), use non failsafe (-nofs) burn flow.",
+                      cntxLog2ChunkSize, imageCntxLog2ChunkSize);
+    }
+    return true;
 }
\ No newline at end of file
