@@ -237,6 +237,8 @@ bool FsCtrlOperations::FsIntQuery()
     _fsCtrlImgInfo.life_cycle = fwQuery.life_cycle;
     _fsCtrlImgInfo.encryption = fwQuery.encryption;
     _fsCtrlImgInfo.ini_file_version = fwQuery.ini_file_version;
+    _fsCtrlImgInfo.geo_address = fwQuery.geo_address;
+    _fsCtrlImgInfo.geo_address_valid = fwQuery.geo_address_valid;
     std::vector<FwComponent> compsMap;
     if (!_fwCompsAccess->getFwComponents(compsMap, false))
     {
@@ -314,26 +316,6 @@ bool FsCtrlOperations::FsIntQuery()
         }
     }
 
-    //* Read global image status
-    if (_fsCtrlImgInfo.sec_boot == true)
-    {
-        try
-        {
-            CRSpaceRegisters cr_space_reg(mf, _fwImgInfo.ext_info.chip_type);
-            _fsCtrlImgInfo.global_image_status = cr_space_reg.getGlobalImageStatus();
-        }
-        catch (logic_error e)
-        {
-            printf("%s\n", e.what());
-            return false;
-        }
-        catch (exception e)
-        {
-            printf("%s\n", e.what());
-            return false;
-        }
-    }
-
     /*
      * Fill ROM info
      */
@@ -464,6 +446,10 @@ bool FsCtrlOperations::FwQuery(fw_info_t* fwInfo,
             return true;
         }
     }
+    else
+    {
+        fwInfo->fs3_info.geo_address_valid = false;
+    }
     return true;
 }
 
