@@ -397,7 +397,7 @@ const u_int32_t FwOperations::_cntx_magic_pattern[4] = {0x4D544657, // Ascii of
 const u_int32_t FwOperations::_fs4_magic_pattern[4] = {0x4D544657, 0xABCDEF00, 0xFADE1234, 0x5678DEAD};
 
 const u_int32_t FwOperations::_cntx_image_start_pos[FwOperations::CNTX_START_POS_SIZE] = {
-  0, 0x10000, 0x20000, 0x40000, 0x80000, 0x100000, 0x200000, 0x400000, 0x800000, 0x1000000};
+  0, 0x10000, 0x20000, 0x40000, 0x80000, 0x100000, 0x200000, 0x400000, 0x800000, 0x1000000, 0x2000000};
 
 bool FwOperations::FindMagicPattern(FBase* ioAccess, u_int32_t addr, u_int32_t const cntx_magic_pattern[])
 {
@@ -2561,8 +2561,8 @@ u_int8_t FwOperations::GetFwFormatFromHwDevID(u_int32_t hwDevId)
         return FS_FS3_GEN;
     }
     else if (hwDevId == CX5_HW_ID || hwDevId == CX6_HW_ID || hwDevId == CX6DX_HW_ID || hwDevId == CX6LX_HW_ID ||
-             hwDevId == CX7_HW_ID || hwDevId == CX8_HW_ID || hwDevId == BF_HW_ID || hwDevId == BF2_HW_ID ||
-             hwDevId == BF3_HW_ID || hwDevId == BF4_HW_ID || hwDevId == QUANTUM_HW_ID || hwDevId == QUANTUM2_HW_ID ||
+             hwDevId == CX7_HW_ID || hwDevId == BF_HW_ID || hwDevId == BF2_HW_ID || hwDevId == BF3_HW_ID ||
+             hwDevId == BF4_HW_ID || hwDevId == QUANTUM_HW_ID || hwDevId == QUANTUM2_HW_ID ||
              hwDevId == SPECTRUM4_HW_ID || hwDevId == SPECTRUM3_HW_ID || hwDevId == SPECTRUM2_HW_ID ||
              hwDevId == GEARBOX_HW_ID || hwDevId == GB_MANAGER_HW_ID || hwDevId == ABIR_GB_HW_ID)
     {
@@ -2938,26 +2938,7 @@ life_cycle_t CRSpaceRegisters::getLifeCycle()
     }
 
     lifeCycle.value = getConsecutiveBits(getRegister(lifeCycleAddress), firstBit, bitLen);
-    
-    return convertToLegacy(lifeCycle);
-}
 
-life_cycle_t CRSpaceRegisters::convertToLegacy(life_cycle_t lifeCycle)
-{
-    if (lifeCycle.version_field == 1)
-    {
-        switch (lifeCycle.value)
-        {
-            case life_cycle_fs5_t::PROD:
-                lifeCycle.value = life_cycle_fs4_t::GA_SECURED;
-                break;
-            case life_cycle_fs5_t::FAILURE_ANALYSIS:
-                lifeCycle.value = life_cycle_fs4_t::RMA;
-                break;
-            default:
-                break;
-        }
-    }
     return lifeCycle;
 }
 
@@ -2965,11 +2946,11 @@ bool CRSpaceRegisters::IsLifeCycleSecured(life_cycle_t life_cycle)
 {
     if (life_cycle.version_field == 1)
     {
-        return (life_cycle.value == PRE_PROD || life_cycle.value == PROD);
+        return (life_cycle.value == FS5_LC_PRE_PRODUCTION || life_cycle.value == FS5_LC_PRODUCTION);
     }
     else
     {
-        return life_cycle.value == GA_SECURED;
+        return life_cycle.value == FS4_LC_GA_SECURED;
     }
 }
 
@@ -2988,12 +2969,14 @@ int CRSpaceRegisters::getGlobalImageStatus()
         case CT_CONNECTX6DX:
         case CT_CONNECTX6LX:
         case CT_CONNECTX7:
-        case CT_CONNECTX8:
         case CT_BLUEFIELD2:
         case CT_BLUEFIELD3:
         case CT_BLUEFIELD4:
             global_image_status_address = 0xE3044;
             break;
+        case CT_CONNECTX8:
+            global_image_status_address = 0x55084;
+            break;
         case CT_QUANTUM2:
         case CT_QUANTUM3:
             global_image_status_address = 0x152080;
