@@ -34,7 +34,7 @@
 #define MLXLINK_ENUMS_H
 
 // Common definitions
-#define AMBER_VERSION "3.3"
+#define AMBER_VERSION "3.6"
 
 #define ACCESS_REG_MCIA "MCIA"
 #define ACCESS_REG_MDDQ "MDDQ"
@@ -983,7 +983,12 @@ enum CABLE_TECHNOLOGY
     TECHNOLOGY_COP_NEAR_FAR_END,
     TECHNOLOGY_COP_FAR_END,
     TECHNOLOGY_COP_NEAR_END,
-    TECHNOLOGY_COP_LINEAR
+    TECHNOLOGY_COP_LINEAR,
+    TECHNOLOGY_LASER_C_BAND,
+    TECHNOLOGY_LASER_L_BAND,
+    TECHNOLOGY_COP_LINEAR_NEAR_FAR_END,
+    TECHNOLOGY_COP_LINEAR_FAR_END,
+    TECHNOLOGY_COP_LINEAR_NEAR_END
 };
 
 enum OUI
@@ -1241,7 +1246,7 @@ enum CMIS_PASSIVE_COPPER_COMPLIANCE
     CMIS_COMPLIANCE_EDR = 0x30,
     CMIS_COMPLIANCE_HDR = 0x31,
     CMIS_COMPLIANCE_NDR = 0x32,
-    CMIS_COMPLIANCE_XDR = 0x33,
+    CMIS_COMPLIANCE_XDR = 0xA0,
     CMIS_COMPLIANCE_100G_BASE_R1 = 0x46,
     CMIS_COMPLIANCE_200G_BASE_R2 = 0x47,
     CMIS_COMPLIANCE_400G_BASE_R4 = 0x48,
@@ -1626,6 +1631,20 @@ enum SLRG_FOM_MODE
     SLRG_FOM_MODE_EYEM_VP
 };
 
+enum SLRG_FOM_MODE_5NM
+{
+    SLRG_FOM_MODE_EYE_OPEN,
+    SLRG_FOM_MODE_EYEO_SNR,
+    SLRG_FOM_MODE_NORM_SNR,
+    SLRG_FOM_MODE_EYE_LVLN,
+    SLRG_FOM_MODE_EYE_LVLP,
+    SLRG_FOM_MODE_THRES_NERR,
+    SLRG_FOM_MODE_CDR_NERR,
+    SLRG_FOM_MODE_CSDET_NERR,
+    SLRG_FOM_MODE_MLSE_NERR,
+    SLRG_FOM_MODE_SFEC_NERR
+};
+
 enum PRBS_PARAMS
 {
     PRBS_PARAMS_RX_TUNING_STATUS,
