@@ -106,6 +106,17 @@ void MlxlinkMaps::initPortStateMapping()
     _slrgFomMode[SLRG_FOM_MODE_EYEM_VN] = "SLRG_FOM_MODE_EYEM_VN";
     _slrgFomMode[SLRG_FOM_MODE_EYEM_VP] = "SLRG_FOM_MODE_EYEM_VP";
 
+    _slrgFomMode5nm[SLRG_FOM_MODE_EYE_OPEN] = "SLRG_FOM_MODE_EYE_OPEN";
+    _slrgFomMode5nm[SLRG_FOM_MODE_EYEO_SNR] = "SLRG_FOM_MODE_EYEO_SNR";
+    _slrgFomMode5nm[SLRG_FOM_MODE_NORM_SNR] = "SLRG_FOM_MODE_NORM_SNR";
+    _slrgFomMode5nm[SLRG_FOM_MODE_EYE_LVLN] = "SLRG_FOM_MODE_EYE_LVLN";
+    _slrgFomMode5nm[SLRG_FOM_MODE_EYE_LVLP] = "SLRG_FOM_MODE_EYE_LVLP";
+    _slrgFomMode5nm[SLRG_FOM_MODE_THRES_NERR] = "SLRG_FOM_MODE_THRES_NERR";
+    _slrgFomMode5nm[SLRG_FOM_MODE_CDR_NERR] = "SLRG_FOM_MODE_CDR_NERR";
+    _slrgFomMode5nm[SLRG_FOM_MODE_CSDET_NERR] = "SLRG_FOM_MODE_CSDET_NERR";
+    _slrgFomMode5nm[SLRG_FOM_MODE_MLSE_NERR] = "SLRG_FOM_MODE_MLSE_NERR";
+    _slrgFomMode5nm[SLRG_FOM_MODE_SFEC_NERR] = "SLRG_FOM_MODE_SFEC_NERR";
+
     _networkPorts["NETWORK"] = NETWORK_PORT_TYPE;
     _networkPorts["PCIE"] = NETWORK_PORT_TYPE_LAST;
     _networkPorts["GEARBOX_HOST"] = NETWORK_PORT_TYPE_NEAR;
@@ -1288,19 +1299,25 @@ void MlxlinkMaps::initCableTechnologyMapping()
     _cableTechnologyQsfp[TECHNOLOGY_850NM_VCSEL] = "850 nm VCSEL";
     _cableTechnologyQsfp[TECHNOLOGY_1310NM_VCSEL] = "1310 nm VCSEL";
     _cableTechnologyQsfp[TECHNOLOGY_1550NM_VCSEL] = "1550 nm VCSEL";
-    _cableTechnologyQsfp[TECHNOLOGY_1310NM_FP] = "1310 nm FP";
-    _cableTechnologyQsfp[TECHNOLOGY_1310NM_DFB] = "1310 nm DFB";
-    _cableTechnologyQsfp[TECHNOLOGY_1550NM_DFB] = "1550 nm DFB";
+    _cableTechnologyQsfp[TECHNOLOGY_1310NM_FP] = "1310 nm FP laser";
+    _cableTechnologyQsfp[TECHNOLOGY_1310NM_DFB] = "1310 nm DFB laser";
+    _cableTechnologyQsfp[TECHNOLOGY_1550NM_DFB] = "1550 nm DFB laser";
     _cableTechnologyQsfp[TECHNOLOGY_1310NM_EML] = "1310 nm EML";
     _cableTechnologyQsfp[TECHNOLOGY_1550NM_EML] = "1550 nm EML";
     _cableTechnologyQsfp[TECHNOLOGY_OTHERS] = "Other / Undefined";
-    _cableTechnologyQsfp[TECHNOLOGY_1490NM_DFB] = "1490 nm DFB";
-    _cableTechnologyQsfp[TECHNOLOGY_COP_UNEQ] = "Copper cable unequalized";
-    _cableTechnologyQsfp[TECHNOLOGY_COP_PASV] = "Copper cable passive equalized";
-    _cableTechnologyQsfp[TECHNOLOGY_COP_NEAR_FAR_END] = "Copper cable, near and far end limiting active equalizers";
-    _cableTechnologyQsfp[TECHNOLOGY_COP_FAR_END] = "Copper cable, far end limiting active equalizers";
-    _cableTechnologyQsfp[TECHNOLOGY_COP_NEAR_END] = "Copper cable, near end limiting active equalizers";
-    _cableTechnologyQsfp[TECHNOLOGY_COP_LINEAR] = "Copper cable, linear active equalizers";
+    _cableTechnologyQsfp[TECHNOLOGY_1490NM_DFB] = "1490 nm DFB laser";
+    _cableTechnologyQsfp[TECHNOLOGY_COP_UNEQ] = "Copper cable, passive, unequalized";
+    _cableTechnologyQsfp[TECHNOLOGY_COP_PASV] = "Copper cable, passive, equalized";
+    _cableTechnologyQsfp[TECHNOLOGY_COP_NEAR_FAR_END] = "Copper cable with near and far end limiting active equalizers";
+    _cableTechnologyQsfp[TECHNOLOGY_COP_FAR_END] = "Copper cable with far end limiting active equalizers";
+    _cableTechnologyQsfp[TECHNOLOGY_COP_NEAR_END] = "Copper cable with near end limiting active equalizers";
+    _cableTechnologyQsfp[TECHNOLOGY_COP_LINEAR] = "Copper cable with linear active equalizers";
+    _cableTechnologyQsfp[TECHNOLOGY_LASER_C_BAND] = "C-band tunable laser";
+    _cableTechnologyQsfp[TECHNOLOGY_LASER_L_BAND] = "B-band tunable laser";
+    _cableTechnologyQsfp[TECHNOLOGY_COP_LINEAR_NEAR_FAR_END] =
+      "Copper cable with near end and far end linear active equalizers";
+    _cableTechnologyQsfp[TECHNOLOGY_COP_LINEAR_FAR_END] = "Copper cable with far end linear active equalizers";
+    _cableTechnologyQsfp[TECHNOLOGY_COP_LINEAR_NEAR_END] = "Copper cable with near end linear active equalizers";
 
     _cableTechnologySfp[0] = "N/A";
     _cableTechnologySfp[4] = "Passive";
