@@ -81,6 +81,12 @@
 #define PCI_VPD_DATA 0x4
 #define HW_ID_ADDR 0xf0014
 
+/* Mellanox VSC */
+#define MLX_VSC_TYPE_OFFSET 24
+#define MLX_VSC_TYPE_LEN 8
+#define FUNCTIONAL_VSC 0
+#define RECOVERY_VSC 2
+
 #define _PATH_DEVPCI "/dev/pci"
 
 typedef enum
@@ -267,7 +273,7 @@ int mtcr_check_signature(mfile* mf)
 
 #define PCI_CONF_ADDR (0x00000058)
 #define PCI_CONF_DATA (0x0000005c)
-#define MLNX_VENDOR_SPECIFIC_CAP_ID 0x9
+#define VENDOR_SPECIFIC_CAP_ID 0x9
 
 /* PCI address space related enum*/
 enum
@@ -290,6 +296,11 @@ enum
     PCI_STATUS_BIT_OFFS = 29,
     PCI_STATUS_BIT_LEN = 3,
 
+    PCI_SYNDROME_BIT_OFFSET = 30,
+    PCI_SYNDROME_BIT_LEN = 1,
+    PCI_SYNDROME_CODE_BIT_OFFSET = 24,
+    PCI_SYNDROME_CODE_BIT_LEN = 4,
+
     PCI_HEADER_OFFS = 0x0,
     PCI_SUBSYS_OFFS = 0x2c,
     PCI_CLASS_OFFS = 0x8,
@@ -319,8 +330,36 @@ int read_config(mfile* mf, unsigned int reg, uint32_t* data, int width)
 
     if (ioctl(mf->fd, PCIOCREAD, &pi) < 0)
     {
-        errno = EIO;
-        return -1;
+        // printf("PCIOCREAD ioctl failed when trying to access this space: %d. errno: %d\n",
+        //             mf->address_space, errno);
+        // support PCI space
+        if (VSEC_PXIR_SUPPORT(mf))
+        {
+            if (mf->address_space < PXIR_SPACE_OFFSET)
+            {
+                mf->address_space += PXIR_SPACE_OFFSET;
+            }
+            else
+            {
+                mf->address_space -= PXIR_SPACE_OFFSET;
+            }
+
+            if (ioctl(mf->fd, PCIOCREAD, &pi) < 0)
+            {
+                errno = EIO;
+                // printf(
+                //     "PCIOCREAD ioctl failed when trying to access this space: %d. errno: %d\n",
+                //     mf->address_space, errno);
+                return -1;
+            }
+            // printf("PCIOCREAD ioctl successfully accessed this space: %d\n",
+            //             mf->address_space);
+        }
+        else
+        {
+            errno = EIO;
+            return -1;
+        }
     }
 
     // printf("%s:  dev:%d reg=%x width=%d data=%x\n", __FUNCTION__, pi.pi_sel.pc_dev, reg, width, pi.pi_data);
@@ -341,8 +380,36 @@ int write_config(mfile* mf, unsigned int reg, uint32_t data, int width)
     // pi.pi_data);
     if (ioctl(mf->fd, PCIOCWRITE, &pi) < 0)
     {
-        errno = EIO;
-        return -1;
+        // printf("PCIOCWRITE ioctl failed when trying to access this space: %d. errno: %d\n",
+        //             mf->address_space, errno);
+        // support PCI space
+        if (VSEC_PXIR_SUPPORT(mf))
+        {
+            if (mf->address_space < PXIR_SPACE_OFFSET)
+            {
+                mf->address_space += PXIR_SPACE_OFFSET;
+            }
+            else
+            {
+                mf->address_space -= PXIR_SPACE_OFFSET;
+            }
+
+            if (ioctl(mf->fd, PCIOCWRITE, &pi) < 0)
+            {
+                errno = EIO;
+                printf(
+                    "PCIOCWRITE ioctl failed when trying to access this space: %d. errno: %d\n",
+                    mf->address_space, errno);
+                return -1;
+            }
+            // printf("PCIOCWRITE ioctl successfully accessed this space: %d\n",
+            //             mf->address_space);
+        }
+        else
+        {
+            errno = EIO;
+            return -1;
+        }
     }
 
     return 0;
@@ -519,6 +586,24 @@ static int _wait_on_flag(mfile* mf, u_int8_t expected_val)
     return 0;
 }
 
+int check_syndrome(mfile* mf)
+{
+    // in case syndrome is set, if syndrome_code is 0x3 (address_out_of_range), return error, so that the ioctl will
+    // fail and then we'll retry with PCI space.
+    uint32_t syndrome = 0;
+    READ4_PCI(mf, &syndrome, mf->vsec_addr + PCI_ADDR_OFFSET, "read domain", return -1);
+    if (syndrome)
+    {
+        uint32_t syndrome_code = 0;
+        READ4_PCI(mf, &syndrome_code, mf->vsec_addr + PCI_CTRL_OFFSET, "read domain", return -1);
+        if (EXTRACT(syndrome_code, PCI_SYNDROME_CODE_BIT_OFFSET, PCI_SYNDROME_CODE_BIT_LEN) == ADDRESS_OUT_OF_RANGE)
+        {
+            return ME_ADDRESS_OUT_OF_RANGE;
+        }
+    }
+    return ME_OK;
+}
+
 static int _set_addr_space(mfile* mf, u_int16_t space)
 {
     // read modify write
@@ -565,6 +650,10 @@ static int _pciconf_rw(mfile* mf, unsigned int offset, uint32_t* data, int rw)
         // read data
         READ4_PCI(mf, data, mf->vsec_addr + PCI_DATA_OFFSET, "read value", return -1);
     }
+    if (VSEC_PXIR_SUPPORT(mf))
+    {
+        ret = check_syndrome(mf);
+    }
     return ret;
 }
 
@@ -655,13 +744,53 @@ static int mread4_new(mfile* mf, unsigned int offset, uint32_t* data)
 
 static int mwrite4_block_new(mfile* mf, unsigned int offset, int size, uint32_t* data)
 {
-    return _block_op(mf, mf->address_space, offset, size, data, WRITE_OP);
-}
+    int rc = _block_op(mf, mf->address_space, offset, size, data, WRITE_OP);
+    if (rc == -1)
+    {
+        // support PCI space
+        if (VSEC_PXIR_SUPPORT(mf))
+        {
+            if (mf->address_space < PXIR_SPACE_OFFSET)
+            {
+                mf->address_space += PXIR_SPACE_OFFSET;
+            }
+            else
+            {
+                mf->address_space -= PXIR_SPACE_OFFSET;
+            }
+            rc = _block_op(mf, mf->address_space, offset, size, data, WRITE_OP);
+            // printf(
+            //   "Entered VSC pci space support flow. PCI address_space now set to: %d. second attempt to run _block_op with VSC PCI address space returned with rc: %d.\n",
+            //   mf->address_space,
+            //   rc);
+        }
+    }
+    return rc;}
 
 static int mread4_block_new(mfile* mf, unsigned int offset, int size, uint32_t* data)
 {
-    return _block_op(mf, mf->address_space, offset, size, data, READ_OP);
-}
+    int rc = _block_op(mf, mf->address_space, offset, size, data, READ_OP);
+    if (rc == -1)
+    {
+        // support PCI space
+        if (VSEC_PXIR_SUPPORT(mf))
+        {
+            if (mf->address_space < PXIR_SPACE_OFFSET)
+            {
+                mf->address_space += PXIR_SPACE_OFFSET;
+            }
+            else
+            {
+                mf->address_space -= PXIR_SPACE_OFFSET;
+            }
+            rc = _block_op(mf, mf->address_space, offset, size, data, READ_OP);
+            // printf(
+            //   "Entered VSC pci space support flow. PCI address_space now set to: %d. second attempt to run _block_op with VSC PCI address space returned with rc: %d.\n",
+            //   mf->address_space,
+            //   rc);
+        }
+    }
+    return rc;}
 
 static int vsec_spaces_supported(mfile* mf)
 {
@@ -887,20 +1016,30 @@ mfile* mopen_int(const char* name, u_int32_t adv_opt)
         _create_lock(mf, real_name);
         mf->wo_addr = is_wo_pciconf_gw(mf);
         // printf("-D- is_wo_pciconf_gw: %d\n", mf->wo_addr);
-        mf->vsec_addr = pci_find_capability(mf, MLNX_VENDOR_SPECIFIC_CAP_ID);
+        mf->vsec_addr = pci_find_capability(mf, VENDOR_SPECIFIC_CAP_ID);
+
+        uint32_t vsec_type = 0;
+        int rc = read_config(mf, mf->vsec_addr, &vsec_type, 4);
+        if (rc)
+        {
+            // printf("-E- Failed to read first dword from VSC - Attempt to read VSC type failed.\n");
+        }
+        mf->vsec_type = EXTRACT(vsec_type, MLX_VSC_TYPE_OFFSET, MLX_VSC_TYPE_LEN);
+        // printf("Device ID: %d mf->wo_addr:%d mf->vsec_addr:%#x mf->vsec_type:%d\n", mf->hw_dev_id, mf->wo_addr, mf->vsec_addr, mf->vsec_type);
+
         mf->vpd_cap_addr = pci_find_capability(mf, PCI_CAP_ID_VPD);
         mf->is_cable = is_cable;
-        mf->vsec_supp = 0;
-        if (mf->vsec_addr)
+        mf->functional_vsec_supp = 0;
+        if (mf->vsec_addr && mf->vsec_type == FUNCTIONAL_VSC)
         {
             if (adv_opt & Clear_Vsec_Semaphore)
             {
                 _vendor_specific_sem(mf, 0);
             }
-            mf->vsec_supp = vsec_spaces_supported(mf);
+            mf->functional_vsec_supp = vsec_spaces_supported(mf);
             mf->address_space = AS_CR_SPACE;
         }
-        // printf("mtcr_open_config Succeeded VSEC_SUPP: %d\n", mf->vsec_supp);
+        // printf("mtcr_open_config Succeeded FUNCTIONAL_VSEC_SUPP: %d\n", mf->functional_vsec_supp);
 #ifndef MST_UL
         if (mf->is_cable)
         {
@@ -1062,7 +1201,7 @@ int mread4(mfile* mf, unsigned int offset, u_int32_t* value)
         }
     }
 #endif
-    if (mf->vsec_supp)
+    if (mf->functional_vsec_supp)
     {
         return mread4_new(mf, offset, value);
     }
@@ -1165,7 +1304,7 @@ int mwrite4(mfile* mf, unsigned int offset, u_int32_t value)
         }
     }
 #endif
-    if (mf->vsec_supp)
+    if (mf->functional_vsec_supp)
     {
         return mwrite4_new(mf, offset, value);
     }
@@ -1226,7 +1365,7 @@ int mread4_block(mfile* mf, unsigned int offset, u_int32_t* data, int byte_len)
         return rc;
     }
 #endif
-    if (mf->vsec_supp)
+    if (mf->functional_vsec_supp)
     {
         int rc = mread4_block_new(mf, offset, byte_len, data);
         // printf("-D- MREAD BLOCK LEN: %d, RC: %d\n", byte_len, rc);
@@ -1251,7 +1390,7 @@ int mwrite4_block(mfile* mf, unsigned int offset, u_int32_t* data, int byte_len)
         return rc;
     }
 #endif
-    if (mf->vsec_supp)
+    if (mf->functional_vsec_supp)
     {
         return mwrite4_block_new(mf, offset, byte_len, data);
     }
@@ -2625,7 +2764,7 @@ int mset_cr_access(mfile* mf, int access)
 
 int mget_vsec_supp(mfile* mf)
 {
-    return mf->vsec_supp;
+    return mf->functional_vsec_supp;
 }
 
 int mget_addr_space(mfile* mf)
@@ -2639,6 +2778,9 @@ int mset_addr_space(mfile* mf, int space)
         case AS_CR_SPACE:
         case AS_ICMD:
         case AS_SEMAPHORE:
+        case AS_PCI_CRSPACE:
+        case AS_PCI_ALL_ICMD:
+        case AS_PCI_GLOBAL_SEMAPHORE:
             break;
 
         default:
@@ -3031,36 +3173,82 @@ int is_remote_dev(mfile* mf)
 }
 
 
-int is_zombiefish_device(mfile* mf)
+static int check_zf_through_memory(mfile* mf)
 {
-    size_t gis_address = 0; // gis == global image status
-    u_int32_t gis = 0;
-    uint32_t gis_operational = 0; // for NICs and HCAs
-
-    u_int32_t hw_dev_id = 0;
-    if (mread4_old(mf, HW_ID_ADDR, &hw_dev_id) != 4) {
-        return 0;
-    }
-
-    switch (hw_dev_id & 0xffff)
+    uint32_t gis = 0; // Global image status
+    size_t gis_address = 0;
+    switch (mf->device_hw_id)
     {
-        case DeviceConnectX8_HwId:
-            gis_address = 0xE3044;
-            break;
         case DeviceQuantum3_HwId:
-            gis_operational = 0x5E;
             gis_address = 0x152080;
             break;
         default:
             return 0; // Device does not support Zombiefish mode
     }
+    int rc = mread4(mf, gis_address, &gis);
 
-    int rc = mread4_old(mf, gis_address, &gis);
     if (rc != 4)
     {
-        // printf("-E- Failed to read global_image_status from CR space.\n");
+        // printf("-E- Failed to read global_image_status from CR space (BAR0).\n");
+        return 0;
+    }
+    gis = EXTRACT(gis, 0, 16); // Extract the first 16 bits
+    return gis == AUTHENTICATION_FAILURE;
+}
+
+static int check_zf_through_vsc(mfile* mf)
+{
+    int prev_address_space = mf->address_space;
+    mset_addr_space(mf, AS_RECOVERY);
+
+    uint32_t first_dword = 0;
+    int rc = mread4(mf, INITIALIZING_BIT_OFFSET_IN_VSC_RECOVERY_SPACE, &first_dword);
+
+    if (rc != 4)
+    {
+        mset_addr_space(mf, prev_address_space);
+        // printf("-E- Failed to read the first dword in VSC recovery space.\n");
         return 0;
     }
 
-    return (gis != gis_operational);
+    uint32_t in_recovery = EXTRACT(first_dword, 1, 1);       // Extract bit 1
+    uint32_t flash_control_vld = EXTRACT(first_dword, 2, 1); // Extract bit 2
+    uint32_t initializing = EXTRACT(first_dword, 0, 1);      // Extract bit 0
+
+    mf->vsc_recovery_space_flash_control_vld = flash_control_vld;
+    mset_addr_space(mf, prev_address_space);
+
+    if (in_recovery && initializing)
+    {
+        // printf("Device with HW ID: %u is in ZombieFish mode. flash_control_vld: %u\n", mf->device_hw_id,
+        //            flash_control_vld);
+        return 1;
+    }
+
+    return 0;
 }
+
+int is_zombiefish_device(mfile* mf)
+{
+    u_int32_t dev_id = 0;
+    if (read_device_id(mf, &dev_id) != 4)
+    {
+        return 0;
+    }
+    if (mf->device_hw_id != DeviceConnectX8_HwId && mf->device_hw_id != DeviceQuantum3_HwId)
+    {
+        return 0;
+    }
+
+    switch (mf->tp)
+    {
+        case MST_PCI:
+            mf->is_zombiefish = check_zf_through_memory(mf);
+            return mf->is_zombiefish;
+        case MST_PCICONF:
+            mf->is_zombiefish = check_zf_through_vsc(mf);
+            return mf->is_zombiefish;
+        default:
+            return 0;
+    }
+}
\ No newline at end of file
