@@ -261,7 +261,7 @@ int supports_reg_access_gmp(mfile* mf, maccess_reg_method_t reg_method)
 
 int mget_vsec_supp(mfile* mf)
 {
-    return mf->vsec_supp;
+    return mf->functional_vsec_supp;
 }
 
 MTCR_API int mget_addr_space(mfile* mf)
@@ -278,8 +278,10 @@ MTCR_API int mset_addr_space(mfile* mf, int space)
     if (VSEC_SUPPORTED_UL(mf) && (mf->vsec_cap_mask & (1 << space_to_cap_offset(space))))
     {
         mf->address_space = space;
+        // printf("VSC address space was set successfully to: %d\n", mf->address_space);
         return 0;
     }
+    // printf("failed to set VSC address space to: %d. mf->address_space = %d\n", space, mf->address_space);
     return -1;
 }
 
