@@ -44,8 +44,8 @@
 #include "packets_common.h"
 #ifndef __FreeBSD__
 #include "mtcr_ib_res_mgt.h"
-#include "tools_dev_types.h"
 #endif
+#include "tools_dev_types.h"
 
 #include "mtcr_mem_ops.h"
 #include "mtcr_ul_com.h"
@@ -170,12 +170,12 @@
  * Macros for accessing Icmd Space
  */
 #define SET_SPACE_FOR_ICMD_ACCESS(mf) \
-    if (mf->vsec_supp)                \
+    if (mf->functional_vsec_supp)                \
     {                                 \
         mset_addr_space(mf, AS_ICMD); \
     }
 #define SET_SPACE_FOR_SEMAPHORE_ACCESS(mf) \
-    if (mf->vsec_supp)                     \
+    if (mf->functional_vsec_supp)                     \
     {                                      \
         mset_addr_space(mf, AS_SEMAPHORE); \
     }
@@ -663,7 +663,7 @@ static int icmd_take_semaphore_com(mfile* mf, u_int32_t expected_read_val)
         else
 #endif
         {
-            if (mf->vsec_supp)
+            if (mf->functional_vsec_supp)
             {
                 // write expected val before reading it
                 MWRITE4_SEMAPHORE(mf, mf->icmd.semaphore_addr, expected_read_val);
@@ -691,7 +691,7 @@ int icmd_take_semaphore(mfile* mf)
     ret = icmd_open(mf);
     CHECK_RC(ret);
 
-    if (mf->vsec_supp)
+    if (mf->functional_vsec_supp)
     {
         if (!pid)
         {
@@ -1250,54 +1250,6 @@ static int is_pci_device(mfile* mf)
 {
     return (mf->flags & MDEVS_I2CM) || (mf->flags & (MDEVS_CABLE | MDEVS_LINKX_CHIP)) || (mf->flags & MDEVS_SOFTWARE);
 }
-
-static int is_livefish_device(mfile* mf)
-{
-    if (!mf || !mf->dinfo)
-    {
-        return 0;
-    }
-    // Make sure to update this table both in mtcr.c & mtcr_ul_com.c !
-    static u_int32_t live_fish_ids[][2] = {{DeviceConnectX4_HwId, DeviceConnectX4_HwId},
-                                           {DeviceConnectX4LX_HwId, DeviceConnectX4LX_HwId},
-                                           {DeviceConnectX5_HwId, DeviceConnectX5_HwId},
-                                           {DeviceConnectX6_HwId, DeviceConnectX6_HwId},
-                                           {DeviceConnectX6DX_HwId, DeviceConnectX6DX_HwId},
-                                           {DeviceConnectX6LX_HwId, DeviceConnectX6LX_HwId},
-                                           {DeviceConnectX7_HwId, DeviceConnectX7_HwId},
-                                           {DeviceBlueField3_HwId, DeviceBlueField3_HwId},
-                                           {DeviceBlueField2_HwId, DeviceBlueField2_HwId},
-                                           {DeviceBlueField_HwId, DeviceBlueField_HwId},
-                                           {DeviceSwitchIB_HwId, DeviceSwitchIB_HwId},
-                                           {DeviceSpectrum_HwId, DeviceSpectrum_HwId},
-                                           {DeviceSwitchIB2_HwId, DeviceSwitchIB2_HwId},
-                                           {DeviceQuantum_HwId, DeviceQuantum_HwId},
-                                           {DeviceQuantum2_HwId, DeviceQuantum2_HwId},
-                                           {DeviceSpectrum2_HwId, DeviceSpectrum2_HwId},
-                                           {DeviceSpectrum3_HwId, DeviceSpectrum3_HwId},
-                                           {DeviceSpectrum4_HwId, DeviceSpectrum4_HwId},
-                                           {0, 0}};
-    int i = 0;
-    unsigned int hwdevid = 0;
-    if (mf->tp == MST_SOFTWARE)
-    {
-        return 1;
-    }
-    int rc = mread4(mf, 0xf0014, &hwdevid);
-    hwdevid &= 0xffff; // otherwise, BF A1 will fail in the searching (0x00010211)
-    if (rc == 4)
-    {
-        while (live_fish_ids[i][0] != 0)
-        {
-            if (live_fish_ids[i][0] == hwdevid)
-            {
-                return (mf->dinfo->pci.dev_id == live_fish_ids[i][1]);
-            }
-            i++;
-        }
-    }
-    return 0;
-}
 #endif
 
 int icmd_open(mfile* mf)
@@ -1320,7 +1272,7 @@ int icmd_open(mfile* mf)
     mf->icmd.ib_semaphore_lock_supported = 0;
     // attempt to open via CR-Space
 #if defined(MST_UL) && !defined(MST_UL_ICMD)
-    if (mf->vsec_supp)
+    if (mf->functional_vsec_supp)
     {
         return icmd_init_vcr(mf);
     }
@@ -1334,7 +1286,7 @@ int icmd_open(mfile* mf)
     /*if (mf->gb_info.is_gearbox){
         return icmd_init_cr(mf);
     }*/
-    if (mf->vsec_supp)
+    if (mf->functional_vsec_supp)
     {
         int rc = icmd_init_vcr(mf);
         if (rc == ME_OK)
@@ -1368,3 +1320,53 @@ void icmd_close(mfile* mf)
         mf->icmd.icmd_opened = 0;
     }
 }
+
+
+int is_livefish_device(mfile* mf)
+{
+    if (!mf || !mf->dinfo)
+    {
+        return 0;
+    }
+    // Make sure to update this table both in mtcr.c & mtcr_ul_com.c !
+    static u_int32_t live_fish_ids[][2] = {{DeviceConnectX4_HwId, DeviceConnectX4_HwId},
+                                           {DeviceConnectX4LX_HwId, DeviceConnectX4LX_HwId},
+                                           {DeviceConnectX5_HwId, DeviceConnectX5_HwId},
+                                           {DeviceConnectX6_HwId, DeviceConnectX6_HwId},
+                                           {DeviceConnectX6DX_HwId, DeviceConnectX6DX_HwId},
+                                           {DeviceConnectX6LX_HwId, DeviceConnectX6LX_HwId},
+                                           {DeviceConnectX7_HwId, DeviceConnectX7_HwId},
+                                           {DeviceConnectX8_HwId, DeviceConnectX8_HwId},
+                                           {DeviceBlueField3_HwId, DeviceBlueField3_HwId},
+                                           {DeviceBlueField2_HwId, DeviceBlueField2_HwId},
+                                           {DeviceBlueField_HwId, DeviceBlueField_HwId},
+                                           {DeviceSwitchIB_HwId, DeviceSwitchIB_HwId},
+                                           {DeviceSpectrum_HwId, DeviceSpectrum_HwId},
+                                           {DeviceSwitchIB2_HwId, DeviceSwitchIB2_HwId},
+                                           {DeviceQuantum_HwId, DeviceQuantum_HwId},
+                                           {DeviceQuantum2_HwId, DeviceQuantum2_HwId},
+                                           {DeviceSpectrum2_HwId, DeviceSpectrum2_HwId},
+                                           {DeviceSpectrum3_HwId, DeviceSpectrum3_HwId},
+                                           {DeviceSpectrum4_HwId, DeviceSpectrum4_HwId},
+                                           {0, 0}};
+    int i = 0;
+    unsigned int hwdevid = 0;
+    if (mf->tp == MST_SOFTWARE)
+    {
+        return 1;
+    }
+    int rc = mread4(mf, 0xf0014, &hwdevid);
+    hwdevid &= 0xffff; // otherwise, BF A1 will fail in the searching (0x00010211)
+    if (rc == 4)
+    {
+        while (live_fish_ids[i][0] != 0)
+        {
+            if (live_fish_ids[i][0] == hwdevid)
+            {
+                return (mf->dinfo->pci.dev_id == live_fish_ids[i][1]);
+            }
+            i++;
+        }
+    }
+    return 0;
+}
\ No newline at end of file
