@@ -41,8 +41,10 @@ void fs5_image_layout_bch_boot_component_flags_pack(const struct fs5_image_layou
 {
 	u_int32_t offset;
 
+	offset = 2;
+	adb2c_push_bits_to_buff(ptr_buff, offset, 30, (u_int32_t)ptr_struct->res);
 	offset = 1;
-	adb2c_push_bits_to_buff(ptr_buff, offset, 31, (u_int32_t)ptr_struct->res);
+	adb2c_push_bits_to_buff(ptr_buff, offset, 1, (u_int32_t)ptr_struct->is_debug);
 	offset = 0;
 	adb2c_push_bits_to_buff(ptr_buff, offset, 1, (u_int32_t)ptr_struct->is_encrypted);
 }
@@ -51,8 +53,10 @@ void fs5_image_layout_bch_boot_component_flags_unpack(struct fs5_image_layout_bc
 {
 	u_int32_t offset;
 
+	offset = 2;
+	ptr_struct->res = (u_int32_t)adb2c_pop_bits_from_buff(ptr_buff, offset, 30);
 	offset = 1;
-	ptr_struct->res = (u_int32_t)adb2c_pop_bits_from_buff(ptr_buff, offset, 31);
+	ptr_struct->is_debug = (u_int8_t)adb2c_pop_bits_from_buff(ptr_buff, offset, 1);
 	offset = 0;
 	ptr_struct->is_encrypted = (u_int8_t)adb2c_pop_bits_from_buff(ptr_buff, offset, 1);
 }
@@ -65,6 +69,8 @@ void fs5_image_layout_bch_boot_component_flags_print(const struct fs5_image_layo
 	adb2c_add_indentation(fd, indent_level);
 	fprintf(fd, "res                  : " UH_FMT "\n", ptr_struct->res);
 	adb2c_add_indentation(fd, indent_level);
+	fprintf(fd, "is_debug             : " UH_FMT "\n", ptr_struct->is_debug);
+	adb2c_add_indentation(fd, indent_level);
 	fprintf(fd, "is_encrypted         : " UH_FMT "\n", ptr_struct->is_encrypted);
 }
 
@@ -179,13 +185,13 @@ void fs5_image_layout_u8_stage1_component_pack(const struct fs5_image_layout_u8_
 	adb2c_push_integer_to_buff(ptr_buff, offset, 4, (u_int32_t)ptr_struct->u32_load_dest);
 	offset = 96;
 	adb2c_push_integer_to_buff(ptr_buff, offset, 4, (u_int32_t)ptr_struct->u32_entry_point);
-	offset = 160;
+	offset = 128;
 	adb2c_push_integer_to_buff(ptr_buff, offset, 4, (u_int32_t)ptr_struct->boot_component_ver);
 	for (i = 0; i < 8; ++i) {
-		offset = adb2c_calc_array_field_address(216, 8, i, 1152, 1);
+		offset = adb2c_calc_array_field_address(184, 8, i, 1152, 1);
 		adb2c_push_bits_to_buff(ptr_buff, offset, 8, (u_int32_t)ptr_struct->u8_res[i]);
 	}
-	offset = 256;
+	offset = 224;
 	fs5_image_layout_bch_boot_component_flags_pack(&(ptr_struct->flags), ptr_buff + offset / 8);
 }
 
@@ -204,13 +210,13 @@ void fs5_image_layout_u8_stage1_component_unpack(struct fs5_image_layout_u8_stag
 	ptr_struct->u32_load_dest = (u_int32_t)adb2c_pop_integer_from_buff(ptr_buff, offset, 4);
 	offset = 96;
 	ptr_struct->u32_entry_point = (u_int32_t)adb2c_pop_integer_from_buff(ptr_buff, offset, 4);
-	offset = 160;
+	offset = 128;
 	ptr_struct->boot_component_ver = (u_int32_t)adb2c_pop_integer_from_buff(ptr_buff, offset, 4);
 	for (i = 0; i < 8; ++i) {
-		offset = adb2c_calc_array_field_address(216, 8, i, 1152, 1);
+		offset = adb2c_calc_array_field_address(184, 8, i, 1152, 1);
 		ptr_struct->u8_res[i] = (u_int8_t)adb2c_pop_bits_from_buff(ptr_buff, offset, 8);
 	}
-	offset = 256;
+	offset = 224;
 	fs5_image_layout_bch_boot_component_flags_unpack(&(ptr_struct->flags), ptr_buff + offset / 8);
 }
 
@@ -517,12 +523,12 @@ void fs5_image_layout_fs5_image_layout_Nodes_print(const union fs5_image_layout_
 	adb2c_add_indentation(fd, indent_level);
 	fprintf(fd, "======== fs5_image_layout_fs5_image_layout_Nodes ========\n");
 
-	adb2c_add_indentation(fd, indent_level);
-	fprintf(fd, "boot_component_header:\n");
-	fs5_image_layout_boot_component_header_print(&(ptr_struct->boot_component_header), fd, indent_level + 1);
 	adb2c_add_indentation(fd, indent_level);
 	fprintf(fd, "hw_pointers_gilboa:\n");
 	fs5_image_layout_hw_pointers_gilboa_print(&(ptr_struct->hw_pointers_gilboa), fd, indent_level + 1);
+	adb2c_add_indentation(fd, indent_level);
+	fprintf(fd, "boot_component_header:\n");
+	fs5_image_layout_boot_component_header_print(&(ptr_struct->boot_component_header), fd, indent_level + 1);
 }
 
 unsigned int fs5_image_layout_fs5_image_layout_Nodes_size(void)
